package com.clx.performance.controller.app;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.clx.performance.param.app.collect.CollectLineReportSendAddressSaveParam;
import com.clx.performance.param.app.collect.PageCollectLineReportParam;
import com.clx.performance.service.collect.CollectLineReportService;
import com.clx.performance.vo.app.collect.CollectLineReportVO;
import com.msl.common.base.PageData;
import com.msl.common.convertor.aspect.UnitCovert;
import com.msl.common.result.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Slf4j
@RestController
@RequestMapping(value="/app/driver/collect/line")
@Validated
@Api(tags = "APP-线路上报")
@AllArgsConstructor
public class AppDriverCollectLineReportController {

    private final CollectLineReportService collectLineReportService;

    @ApiOperation(value = "上报货源地情况", notes = "<br>By:艾庆国")
    @PostMapping("/saveSendAddressReport")
    public Result<Void> saveSendAddressReport(@RequestBody @Validated CollectLineReportSendAddressSaveParam param) {
        collectLineReportService.saveSendAddressReport(param);

        return Result.ok();
    }

    @ApiOperation(value = "查询线路上报详情", notes = "<br>By:艾庆国")
    @GetMapping("/getReportInfo")
    public Result<CollectLineReportVO> getReportInfo(Integer id) {

        return Result.ok(collectLineReportService.getReportInfo(id));
    }

    @ApiOperation(value = "分页查询线路上报列表",notes = "<br>By:艾庆国")
    @PostMapping("/pageLineReport")
    @UnitCovert(param = false)
    public Result<PageData<CollectLineReportVO>> pageLineReport(@RequestBody @Validated PageCollectLineReportParam param) {
        IPage<CollectLineReportVO> page = collectLineReportService.pageLineReport(param);
        return Result.page(page.getRecords(), page.getTotal(), page.getPages());
    }

}
